/**
 * Ristinolla / Pelaaja-interface
 *
 * Pelaajien (ihminen taikka tietokone) on toteutettava tm interface,
 * jotta Ruudukko-Pelaaja -api toimaa kuten kuuluu.
 *
 * Ruudukko-luokan osalta apiin kuuluu lhinn vain annaSiirto, jolla ihmispelaajat
 * voivat pyyt seuraavaa hiirulaisen/nppimistn luomaa siirtoa:
 *
 * public int[] annaSiirto();
 *
 * joka palauttaa int[2]-taulukon, jossa [0] siirron x-ruutu, [1] siirron y-ruutu.
 *
 * @author Samuli Kaipiainen
 * @version 1.0
 */

public interface Pelaaja
{
	/**
	 * Kertoo pelaajalle ruudukon, johon pelaaja liittyy ja jonka palveluja
	 * pelaaja voi kytt, sek kyseisen ruudukon koon ruutuina.
	 *
	 * Ruudukon tulee kutsua tt ennen kuin ottaa pelaajan kyttn, eli ennen
	 * ensimmist uusiPeli-ilmoitusta, jotta pelaajalle ei tule itku;
	 * tai jos ruudukon koko muuttuu (mieluiten ei kesken pelin, toiminta mrittelemtn).
	 *
	 * Pelaajan tulee palauttaa kutsu mahdollisimman pian.
	 *
	 * @param ruudukko Ruudukko, johon kyseinen Pelaaja liittyy
	 * @param leveys ruudukon leveys ruutuina
	 * @param korkeus ruudukon korkeus ruutuina
	 */
	public void asetaRuudukko(Ruudukko ruudukko, int leveys, int korkeus);

	/**
	 * Ruudukko ilmoittaa tll kaikille pelaajille uuden pelin alkaneen.
	 *
	 * Ensin kaikki (molemmat) pelaajat saavat uusiPeli-ilmoituksen, joka pelaajan
	 * tulee palauttaa mahdollisimman pian. Sen jlkeen pelin aloittava pelaaja
	 * saa ensimmisen siirto-kutsun.
	 */
	public void uusiPeli();

	/**
	 * Ruudukko kertoo toisen pelaajan skeisen siirron vuorossa olevalle pelaajalle,
	 * ilmoittaa implisiittisesti pelaajalle hnen vuoronsa alkaneen, ja pyyt
	 * samalla seuraavan siirron kyseiselt vuoron saaneelta pelaajalta.
	 *
	 * Jos edellinen siirto on (-1, -1), ei ole edellisi siirtoja, eli vuorossa on
	 * pelin ensimminen siirto.
	 *
	 * Jos taas edellinen siirto on sama, kuin mik edellisell siirto-kutsulla saatiin,
	 * oli viimeksi palautettu uusi siirto virheellinen; pelaajan tulee yritt eri siirtoa
	 * kuin viimeksi, taikka peli j jumiin...
	 *
	 * @param x edellisen (toisen pelaajan) siirron x-ruutu
	 * @param y edellisen (toisen pelaajan) siirron y-ruutu
	 * @return int[2]-taulukko, jossa [0] uuden siirron x-ruutu, [1] uuden siirron y-ruutu; null luovutus
	 */
	public int[] siirto(int x, int y);
}
